@@ -1,4 +1,4 @@
-/*	$Id: Class1.h,v 1.24 2004/09/20 19:18:05 lhoward Exp $ */
+/*	$Id: Class1.h,v 1.38 2005/09/27 18:44:10 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -29,6 +29,7 @@
  * EIA/TIA-578 (Class 1) Modem Driver.
  */
 #include "FaxModem.h"
+#include "FaxParams.h"
 
 class HDLCFrame;
 
@@ -51,13 +52,15 @@ protected:
     fxStr	rhCmd;			// command for receiving a frame
     fxStr	classCmd;		// set class command
     u_int	serviceType;		// modem service required
-    u_int	dis;			// current remote DIS
-    u_int	xinfo;			// current remote DIS extensions
+    FaxParams	dis_caps;		// current remote DIS
     u_int	frameSize;		// size of image frames
     u_int	signalRcvd;		// last signal received in ECM protocol
+    fxStr	frameRcvd;		// last frame received from the remote
+    fxStr	signalSent;		// last signal sent to remote
     u_int	nonV34br;		// modemParams.br without V.34
     bool	sendERR;		// T.30-A send ERR instead of MCF
     bool	hadV34Trouble;		// indicates failure due to V.34 restrictions
+    bool	hadV17Trouble;		// indicates failure due to V.17 problems
     bool	batchingError;		// indicates failure due to batching protocol
     const u_char* frameRev;		// HDLC frame bit reversal table
     fxStr	lid;			// encoded local id string
@@ -67,10 +70,12 @@ protected:
     Class1Cap	recvCaps[15];		// modem recv capabilities
     const Class1Cap* curcap;		// capabilities being used
     u_int	discap;			// DIS signalling rate capabilities
-    bool	prevPage;		// a previous page was received
+    u_int	prevPage;		// count of previous pages received
+    u_int	prevBlock;		// count of previous blocks (of this page) received
     bool	pageGood;		// quality of last page received
     bool	recvdDCN;		// received DCN frame
     bool	messageReceived;	// expect/don't expect message carrier
+    bool	repeatPhaseB;		// return to beginning of Phase B before next page
     u_int	lastPPM;		// last PPM during receive
     bool	sendCFR;		// received TCF was not confirmed
     u_short	ecmBitPos;		// bit position to populate on ecmByte
@@ -82,7 +87,7 @@ protected:
     u_long	ecmBlockPos;		// fill pointer for ecmBlock
     u_char*	ecmStuffedBlock;	// to hold image block after adding transparent zeros and FCS bytes
     u_long	ecmStuffedBlockPos;	// fill pointer for ecmStuffedBlockPos
-    u_short	frameNumber;		// frame sequence number of ecmFrame in ecmBlock
+    u_int	frameNumber;		// frame sequence number of ecmFrame in ecmBlock
     u_short	blockNumber;		// block sequence number of ecmBlock in page
 
     static const u_int modemPFMCodes[8];// map T.30 FCF to Class 2 PFM
@@ -115,14 +120,14 @@ protected:
     virtual bool setupClass1Parameters();
     virtual bool setupFlowControl(FlowControl fc);
 // transmission support
-    bool	sendPrologue(u_int dcs, u_int xinfo, const fxStr& tsi);
+    bool	sendPrologue(FaxParams& dcs_caps, const fxStr& tsi);
     bool	dropToNextBR(Class2Params&);
     bool	raiseToNextBR(Class2Params&);
     bool	sendTraining(Class2Params&, int, fxStr& emsg);
     bool	sendTCF(const Class2Params&, u_int ms);
     bool	sendPage(TIFF* tif, Class2Params&, u_int, u_int, fxStr& emsg);
     bool	sendPageData(u_char* data, u_int cc, const u_char* bitrev, bool ecm, fxStr& emsg);
-    bool	sendRTC(Class2Params params, u_int ppmcmd, int lastbyte, fxStr& emsg);
+    bool	sendRTC(Class2Params params, u_int ppmcmd, int lastbyte, uint32 rowsperstrip, fxStr& emsg);
     bool	sendPPM(u_int ppm, HDLCFrame& mcf, fxStr& emsg);
     bool	decodePPM(const fxStr& pph, u_int& ppm, fxStr& emsg);
 // reception support
@@ -132,18 +137,20 @@ protected:
 		    u_int f2, const fxStr& addr,
 		    u_int f3, const fxStr& nsf,
 		    u_int f4, const fxStr& id,
-		    u_int f5, u_int dics, u_int xinfo,
+		    u_int f5, FaxParams& dics,
 		    u_int timer, fxStr& emsg);
     bool	recvDCSFrames(HDLCFrame& frame);
     bool	recvTraining();
     bool	recvPPM(int& ppm, fxStr& emsg);
     bool	recvPageData(TIFF*, fxStr& emsg);
+    bool	raiseRecvCarrier(bool& dolongtrain, fxStr& emsg);
     void	recvData(TIFF*, u_char* buf, int n);
     void	processDCSFrame(const HDLCFrame& frame);
     void	abortPageRecv();
 // miscellaneous
     enum {			// Class 1-specific AT responses
-	AT_FCERROR	= 100 	// "+FCERROR"
+	AT_FCERROR	= 100, 	// "+FCERROR"
+	AT_FRH3		= 101,	// "+FRH:3"
     };
     virtual ATResponse atResponse(char* buf, long ms = 30*1000);
     virtual bool waitFor(ATResponse wanted, long ms = 30*1000);
@@ -154,15 +161,17 @@ protected:
     const fxStr& decodePWD(fxStr& ascii, const HDLCFrame& binary);
     const Class1Cap* findSRCapability(u_short sr, const Class1Cap[]);
     const Class1Cap* findBRCapability(u_short br, const Class1Cap[]);
+    static bool isCapable(u_int sr, FaxParams& dis);
 // class 1 HDLC frame support
+    bool	transmitFrame(fxStr& signal);
     bool	transmitFrame(u_char fcf, bool lastFrame = true);
-    bool	transmitFrame(u_char fcf, u_int, u_int, bool lastFrame = true);
+    bool	transmitFrame(u_char fcf, FaxParams& dcs_caps, bool lastFrame = true);
     bool	transmitFrame(u_char fcf, const fxStr&, bool lastFrame=true);
     bool	transmitFrame(u_char fcf, const u_char* code, const fxStr&, bool lastFrame=true);
     bool	transmitData(int br, u_char* data, u_int cc,
 		    const u_char* bitrev, bool eod);
     bool	sendFrame(u_char fcf, bool lastFrame = true);
-    bool	sendFrame(u_char fcf, u_int, u_int, bool lastFrame = true);
+    bool	sendFrame(u_char fcf, FaxParams& dcs_caps, bool lastFrame = true);
     bool	sendFrame(u_char fcf, const fxStr&, bool lastFrame = true);
     bool	sendFrame(u_char fcf, const u_char* code, const fxStr&, bool lastFrame = true);
     bool	sendRawFrame(HDLCFrame& frame);
@@ -170,7 +179,7 @@ protected:
 		    const u_char* bitrev, bool eod);
     bool	sendClass1ECMData(const u_char* data, u_int cc,
 		     const u_char* bitrev, bool eod, u_int ppmcmd, fxStr& emsg);
-    bool	recvFrame(HDLCFrame& frame, long ms = 10*1000);
+    bool	recvFrame(HDLCFrame& frame, u_char dir, long ms = 10*1000, bool readPending = false);
     bool	recvTCF(int br, HDLCFrame&, const u_char* bitrev, long ms);
     bool	recvRawFrame(HDLCFrame& frame);
     bool	recvECMFrame(HDLCFrame& frame);
@@ -182,7 +191,7 @@ protected:
     bool	blockFrame(const u_char* bitrev, bool lastframe, u_int ppmcmd, fxStr& emsg);
     bool	endECMBlock();
     void	abortReceive();
-    void	traceHDLCFrame(const char* direction, const HDLCFrame& frame);
+    void	traceHDLCFrame(const char* direction, const HDLCFrame& frame, bool isecm = false);
 // class 1 command support routines
     bool	class1Query(const fxStr& queryCmd, Class1Cap caps[]);
     bool	parseQuery(const char*, Class1Cap caps[]);
@@ -204,8 +213,7 @@ public:
 
 // receive support
     CallType	answerCall(AnswerType, fxStr& emsg, const char* number);
-    u_int	modemDIS() const;
-    u_int	modemXINFO() const;
+    FaxParams	modemDIS() const;
     bool	setupReceive();
     bool	recvBegin(fxStr& emsg);
     bool	recvEOMBegin(fxStr& emsg);
