@@ -1,4 +1,4 @@
-/*	$Id: ClassModem.h,v 1.18 2005/01/01 21:27:15 lhoward Exp $ */
+/*	$Id: ClassModem.h,v 1.20 2005/02/14 13:56:29 lhoward Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -30,6 +30,7 @@
  */
 #include <stdarg.h>
 #include "Str.h"
+#include "CallID.h"
 
 class ModemServer;
 class ModemConfig;
@@ -55,11 +56,6 @@ typedef struct {
     CallType	type;		// resultant call type
 } AnswerMsg;
 
-typedef struct {
-    fxStr	number;		// caller's phone number
-    fxStr	name;		// caller's identity
-} CallerID;
-
 /*
  * AT command escape codes.  Command strings specified in the
  * modem configuration file are parsed and embedded commands
@@ -189,6 +185,7 @@ private:
     BaudRate	rate;		// selected DTE-DCE communication rate
     FlowControl	iFlow;		// input flow control scheme
     FlowControl	oFlow;		// output flow control scheme
+    fxStr	dialedNumber;	// number dialed
 protected:
 // NB: these are defined protected for convenience (XXX)
     const ModemConfig& conf;	// configuration parameters
@@ -329,7 +326,7 @@ public:
      * with recvAbort available to abort a receive
      * at any time in this procedure.
      */
-    virtual bool waitForRings(u_short rings, CallType&, CallerID&);
+    virtual bool waitForRings(u_short rings, CallType&, CallID&);
     virtual CallType answerCall(AnswerType, fxStr& emsg, const char* dialnumber = NULL);
     virtual void answerCallCmd(CallType);
 };
