@@ -1,4 +1,4 @@
-/*	$Id: FaxModem.h,v 1.28 2004/09/20 19:18:07 lhoward Exp $ */
+/*	$Id: FaxModem.h,v 1.37 2005/09/27 19:18:26 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -34,6 +34,7 @@
 #include "G3Decoder.h"
 #include "FaxSendStatus.h"
 #include "NSF.h"
+#include "FaxParams.h"
 
 class FaxMachineInfo;
 class fxStackBuffer;
@@ -59,6 +60,7 @@ private:
 // transmit tag line support
     u_int	pageNumber;	// current transmit page number
     u_int	pageNumberOfJob;// current transmit page number of Job
+    u_int	pageNumberOfCall;// current transmit page number of call
     FaxFont*	tagLineFont;	// font for imaging tag line
     u_int	tagLineSlop;	// extra space reserved for tag line re-encoding
     fxStr	tagLine;	// tag line formatted with transmit time
@@ -74,7 +76,10 @@ private:
     u_long	recvConsecutiveBadLineCount;
     tstrip_t	recvStrip;	// current strip number during receive
     u_char*	recvRow;	// current receive row raster
-    u_long	savedWriteOff;	// file offset to start of page data
+    u_char*	recvPageStart;	// pointer to start of page buffer
+    u_long*	savedWriteOff;	// file offset at start of page data
+    u_long*	savedStripByteCounts;	// byte counts at start of page data
+    int		decodedPixels;	// number of pixels decoded with error
     int		decoderFd[2];	// file descriptors for the decoder pipe
     int		counterFd[2];	// file descriptors for the counter pipe
     pid_t	decoderPid;	// process id for the decoding process
@@ -103,12 +108,13 @@ protected:
     u_int       recvFillOrder;  // bit order of recvd data (ModemConfig & autodetected)
     u_int       sendFillOrder;  // bit order of sent data (ModemConfig & autodetected)
     const u_char* rtcRev;       // bit reversal table for RTC
+    bool	pageStarted;	// recvStartPage has been called
 
     FaxModem(FaxServer&, const ModemConfig&);
 
 // miscellaneous
     void	countPage();
-    int		getPageNumber();
+    int		getPageNumberOfCall();
     void	recvTrace(const char* fmt, ...);
     void	copyQualityTrace(const char* fmt, ...);
     void	traceModemParams();
@@ -116,6 +122,7 @@ protected:
     void	tracePPM(const char* dir, u_int ppm);
 // server-related stuff
     bool	getHDLCTracing();
+    bool	getECMTracing();
     FaxSendStatus sendSetupParams(TIFF*, Class2Params&,
 		    FaxMachineInfo&, fxStr&);
     void	recvTSI(const fxStr&);
@@ -136,6 +143,7 @@ protected:
     void	setupStartPage(TIFF* tif, const Class2Params& params);
     void	recvEndPage(TIFF* tif, const Class2Params& params);
     void	writeECMData(TIFF*, u_char*, u_int, const Class2Params&, u_short);
+    void	resetLineCounts();
     void	initializeDecoder(const Class2Params&);
     virtual void abortPageRecv() = 0;
     virtual int nextByte();
@@ -153,17 +161,18 @@ protected:
  * Correct if neccessary Phase C (T.4/T.6) data (remove extra RTC/EOFB etc.)
  */
     int		correctPhaseCData(u_char* buf, u_long* pBufSize,
-                                  u_int fillorder, const Class2Params& params);
+                                  u_int fillorder, const Class2Params& params, uint32& rows);
 /*
  * Convert Phase C data...
  */
     u_char*	convertPhaseCData(u_char* buf, u_long& totdata, u_int fillorder,
-                            const Class2Params& params, const Class2Params& newparams);
+                            const Class2Params& params, const Class2Params& newparams, uint32& rows);
 public:
     enum {			// FaxModem::RTNHandling
         RTN_RETRANSMIT = 0,         // retransmit page after RTN until MCF/MPS
         RTN_GIVEUP     = 1,         // immediately abort
-        RTN_IGNORE     = 2          // ignore error and send next page
+        RTN_IGNORE     = 2,         // ignore error and send next page
+        RTN_RETRANSMITIGNORE = 3    // retransmit but ignore error instead of hanging up
     };
 
     virtual ~FaxModem();
@@ -176,6 +185,7 @@ public:
 // methods for querying modem capabilities
     virtual bool supports2D() const;
     virtual bool supportsMMR() const;
+    virtual bool supportsJBIG() const;
     virtual bool supportsEOLPadding() const;
     virtual bool supportsVRes(float res) const;
     virtual bool supportsPageWidth(u_int w, u_int r) const;
@@ -194,8 +204,7 @@ public:
     u_int getBestPageWidth() const;
     u_int getBestPageLength() const;
     u_int getBestECM() const;
-    u_int modemDIS() const;
-    u_int modemXINFO() const;
+    FaxParams modemDIS() const;
 
     /*
      * Fax send protocol.  The expected sequence is:
