@@ -1,4 +1,4 @@
-/*	$Id: FaxServer.h,v 1.14 2004/11/16 14:55:04 aidan Exp $ */
+/*	$Id: FaxServer.h,v 1.17 2005/05/06 17:21:19 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -57,7 +57,9 @@ private:
     time_t	connTime;		// time connected to peer
     time_t	fileStart;		// starting time for file transmit
     time_t	pageStart;		// starting time for page transmit
+    time_t	pageTransferTime;	// transfer time for last page
     u_int	npages;			// # pages sent/received
+    fxStr	batchid;		// Batch ID, for session logs
 
     friend class FaxModem;
 
@@ -92,10 +94,11 @@ protected:
     void	setLocalIdentifier(const fxStr& lid);
 
     void	sendFax(FaxRequest&, FaxMachineInfo&, FaxAcctInfo&, u_int&);
-    bool	recvFax(const CallerID& cid, fxStr& emsg);
+    bool	recvFax(const CallID& callid, fxStr& emsg);
 
     time_t	getFileTransferTime() const;
     time_t	getPageTransferTime() const;
+    time_t	setPageTransferTime();
     time_t	getConnectTime() const;
     const Class2Params& getClientParams() const;
 
@@ -104,12 +107,12 @@ protected:
     virtual void notifyConnected(const FaxRequest&);
     virtual void notifyPageSent(FaxRequest&, const char*);
     virtual void notifyDocumentSent(FaxRequest&, u_int index);
-    virtual void notifyPollRecvd(FaxRequest&, const FaxRecvInfo&);
+    virtual void notifyPollRecvd(FaxRequest&, FaxRecvInfo&);
     virtual void notifyPollDone(FaxRequest&, u_int index);
-    virtual void notifyRecvBegun(const FaxRecvInfo&);
-    virtual void notifyPageRecvd(TIFF* tif, const FaxRecvInfo&, int ppm);
-    virtual void notifyDocumentRecvd(const FaxRecvInfo& req);
-    virtual void notifyRecvDone(const FaxRecvInfo& req);
+    virtual void notifyRecvBegun(FaxRecvInfo&);
+    virtual void notifyPageRecvd(TIFF* tif, FaxRecvInfo&, int ppm);
+    virtual void notifyDocumentRecvd(FaxRecvInfo& req);
+    virtual void notifyRecvDone(FaxRecvInfo& req);
 public:
     virtual ~FaxServer();
 
