@@ -1,4 +1,4 @@
-/*	$Id: ModemConfig.h,v 1.35 2005/01/01 21:27:15 lhoward Exp $ */
+/*	$Id: ModemConfig.h,v 1.41 2005/10/20 20:05:27 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -31,6 +31,23 @@
 #include "FaxConfig.h"
 #include "FaxModem.h"
 
+#include "Array.h"
+
+class id_config
+{
+    public:
+	fxStr	pattern;
+	int	answerlength;
+
+	int compare (const id_config* n) const
+	{
+	    return ::compare(pattern, n->pattern);
+	}
+
+};
+
+fxDECLARE_ObjArray(IDConfArray, id_config);
+
 struct ModemConfig : public FaxConfig {
 private:
     BaudRate	getRate(const char*);
@@ -57,6 +74,8 @@ protected:
     virtual void configError(const char* fmt, ...) = 0;
     virtual void configTrace(const char* fmt, ...) = 0;
     fxStr parseATCmd(const char*);
+
+    u_int	callidIndex;		// call id index
 public:
     fxStr	type;			// modem type
     fxStr	resetCmds;		// extra modem reset commands for start of initialization
@@ -105,11 +124,8 @@ public:
     fxStr	dringOn;		// pattern for distinctive ring silence interval
     fxStr	dringOff;		// pattern for distinctive ring ring interval
     bool	noAnswerVoice;		// leave voice calls unanswered
-					// caller id
-    fxStr	cidName;		// pattern for name info
-    fxStr	cidNumber;		// pattern for number info
-    u_int	cidNameAnswerLength;	// answer when CID received
-    u_int	cidNumberAnswerLength;	// answer when CID received
+					// call identification
+    IDConfArray	idConfig;		// pattern for ID info
 					// protocol timers
     u_int	t1Timer;		// T.30 T1 timer (ms)
     u_int	t2Timer;		// T.30 T2 timer (ms)
@@ -120,6 +136,7 @@ public:
     u_int	pageDoneTimeout;	// page send/receive timeout (ms)
 					// for class 1:
     fxStr	class1Cmd;		// cmd for setting Class 1
+    fxStr	class1AdaptRecvCmd;	// cmd to enable adaptive reception control
     fxStr	class1EnableV34Cmd;	// cmd to enable V.34 support in Class 1.0
     fxStr	class1NFLOCmd;		// cmd to setup no flow control
     fxStr	class1SFLOCmd;		// cmd to setup software flow control
@@ -133,10 +150,10 @@ public:
     fxStr	class1SwitchingCmd;	// after recv HDLC and before sending
     fxStr	class1MsgRecvHackCmd;	// cmd to avoid +FCERROR before image
     u_int	class1TCFRecvTimeout;	// timeout receiving TCF
-    u_int	class1TCFResponseDelay;	// delay (ms) btwn TCF & ack/nak
     u_int	class1SendMsgDelay;	// delay (ms) after training
     u_int	class1TrainingRecovery;	// delay (ms) after failed training
     u_int	class1RecvAbortOK;	// if non-zero, OK sent after recv abort
+    u_int	class1RMPersistence;	// how many times to persist through +FCERROR
     u_int	class1Resolutions;	// resolutions support
     u_int	class1FrameOverhead;	// overhead bytes in received frames
     u_int	class1RecvIdentTimer;	// timeout receiving initial identity
@@ -144,6 +161,9 @@ public:
     u_int	class1TCFMinRun;	// min length of zero run for TCF check
     u_int	class1TMConnectDelay;	// delay (ms) after +FTM CONNECT
     u_int	class1ECMFrameSize;	// ECM frame size for transmission
+    bool	class1GreyJPEGSupport;	// Greyscale JPEG support
+    bool	class1ColorJPEGSupport;	// Full-color JPEG support
+    bool	class1JBIGSupport;	// monochrome JBIG support
     bool	class1ECMSupport;	// support T.30-A ECM
     bool	class1PersistentECM;	// continue to correct
     bool	class1TCFRecvHack;	// deliberately look for V.21 disconnect
@@ -221,7 +241,7 @@ public:
 
         virtual ~ModemConfig();
 
-    void parseCID(const char*, CallerID&) const;
+    void parseCallID(const char*, CallID&) const;
     const fxStr& getFlowCmd(FlowControl) const;
     void parseDR(const char*);
     void processDRString(char*, const u_int);
