@@ -1,4 +1,4 @@
-/*	$Id: ModemServer.h,v 1.8 2004/06/01 21:34:42 lhoward Exp $ */
+/*	$Id: ModemServer.h,v 1.12 2005/04/19 17:46:35 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -86,6 +86,7 @@ private:
     u_short	rcvBit;			// pending bit of rcvNext to send
     int		gotByte;		// byte held for bit destruction
     bool	sawBlockEnd;		// whether DLE+ETX has been seen
+    bool	inputBuffered;		// whether or not modem input is buffered
     u_char	rcvBuf[1024];		// receive buffering
 
     friend class ClassModem;
@@ -158,7 +159,7 @@ protected:
     bool	setInputBuffering(bool on);
     bool	modemStopOutput();
 // modem driver interfaces
-    bool	modemWaitForRings(u_short rings, CallType&, CallerID&);
+    bool	modemWaitForRings(u_short rings, CallType&, CallID&);
     CallType	modemAnswerCall(AnswerType, fxStr&, const char* dialnumber = NULL);
     void	modemAnswerCallCmd(CallType);
     void	modemFlushInput();
