@@ -1,4 +1,4 @@
-/* $Id: NSF.h,v 1.5 2004/05/22 02:12:36 lhoward Exp $ */
+/* $Id: NSF.h,v 1.6 2005/09/27 18:30:40 lhoward Exp $ */
 /* 
  * This file does not exist in the original HylaFAX distribution.
  * Created by Dmitry Bely, April 2000
@@ -60,7 +60,7 @@ private:
     void clear();
     void loadHexData( const char* hexNSF, bool useHex );
     void loadRawData( const u_char* rawData, int size, const u_char* revTab );
-    void findStationId( bool reverseOrder, bool reverseBitOrder );
+    void findStationId( bool reverseOrder );
     void decode();
 };
 
