@@ -1,4 +1,4 @@
-/*	$Id: faxQueueApp.h,v 1.11 2004/08/30 18:26:04 lhoward Exp $ */
+/*	$Id: faxQueueApp.h,v 1.20 2005/09/27 18:54:21 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -69,17 +69,20 @@ private:
     class SchedTimeout : public IOHandler {
     private:
 	bool	started;
+	bool	pending;
+	time_t	lastRun;		// time of last scheduler run
     public:
 	SchedTimeout();
 	~SchedTimeout();
 	void timerExpired(long, long);
 
-	void start();
+	void start(u_short s = 0);
     };
 // configuration stuff
     fxStr	configFile;		// configuration filename
     fxStr	contCoverPageTemplate;	// continuation cover page template
     u_int	postscriptTimeout;	// timeout on PostScript imager calls
+    u_int	maxBatchJobs;		// max jobs in a batch
     u_int	maxConcurrentCalls;	// max parallel jobs to a destination
     u_int	maxSendPages;		// max pages in a send job
     u_int	maxDials;		// max times to dial the phone for a job
@@ -101,6 +104,7 @@ private:
     fxStr	logFacility;		// syslog facility to direct trace msgs
     u_int	requeueInterval;	// job requeue interval
     bool	use2D;			// ok to use 2D-encoded data
+    bool	useUnlimitedLN;		// ok to use unlimited page length
     u_int	pageChop;		// default page chop handling
     float	pageChopThreshold;	// minimum space before page chop
     fxStr	notifyCmd;		// external command for notification
@@ -196,7 +200,7 @@ private:
 		    DestInfo&, const DestControlInfo&);
     void	sendJobStart(Job&, FaxRequest*, const DestControlInfo&);
     void	sendJobDone(Job& job, int status);
-    void	sendJobDone(Job& job, FaxRequest* req, int status);
+    void	sendJobDone(Job& job, FaxRequest* req);
     void	blockJob(Job&, FaxRequest&, const char*);
     void	delayJob(Job&, FaxRequest&, const char*, time_t);
     void	rejectJob(Job& job, FaxRequest& req, const fxStr& reason);
@@ -213,12 +217,16 @@ private:
     bool	submitJob(Job& job, FaxRequest& req, bool checkState = false);
     bool	suspendJob(Job& job, bool abortActive);
     bool	terminateJob(const fxStr& filename, JobStatus why);
+    void	timeoutAccounting(Job& job, FaxRequest&);
     void	timeoutJob(Job& job);
     void	timeoutJob(Job& job, FaxRequest&);
     void	runJob(Job& job);
 
+    void	removeDestInfoJob(Job& job);
+    void        unblockDestJobs(Job& job, DestInfo& di);
+
     void	runScheduler();
-    void	pokeScheduler();
+    void	pokeScheduler(u_short s = 0);
 // job preparation stuff
     bool	prepareJobNeeded(Job&, FaxRequest&, JobStatus&);
     static void prepareCleanup(int s);
