@@ -1,4 +1,4 @@
-/*	$Id: HylaFAXServer.h,v 1.11 2004/11/23 18:05:02 lhoward Exp $ */
+/*	$Id: HylaFAXServer.h,v 1.15 2005/09/27 19:14:29 lhoward Exp $ */
 /*
  * Copyright (c) 1995-1996 Sam Leffler
  * Copyright (c) 1995-1996 Silicon Graphics, Inc.
@@ -43,7 +43,6 @@
 #ifdef HAVE_PAM
 extern "C" {
 #include <security/pam_appl.h>
-#include <security/pam_misc.h>
 #include <grp.h>
 }
 #endif // HAVE_PAM
@@ -118,7 +117,7 @@ enum Token {
      */
     T_ACCTINFO,	 T_BEGBR,	T_BEGST,	T_CHOPTHRESH,	T_CLIENT,
     T_COMMENTS,	 T_COMMID,	T_COVER,	T_DATAFORMAT,	T_DIALSTRING,
-    T_DOCUMENT,	 T_DONEOP,	T_EXTERNAL,	T_FROM_COMPANY,	T_FROM_LOCATION,
+    T_DOCUMENT,	 T_DONEOP,	T_EXTERNAL,	T_FAXNUMBER,	T_FROM_COMPANY,	T_FROM_LOCATION,
     T_FROM_USER, T_FROM_VOICE,	T_GROUPID,	T_HRES,		T_JOBID,
     T_JOBINFO,	 T_JOBTYPE,	T_LASTTIME,	T_MAXDIALS,	T_MAXPAGES,
     T_MAXTRIES,	 T_MINBR,	T_MODEM,	T_NDIALS,	T_NOTIFY,
@@ -126,7 +125,7 @@ enum Token {
     T_PAGELENGTH,T_PAGEWIDTH,	T_PASSWD,	T_POLL,		T_REGARDING,
     T_RETRYTIME, T_SCHEDPRI,	T_SENDTIME,	T_STATE,	T_STATUS,
     T_SUBADDR,	 T_TAGLINE,	T_TOTDIALS,	T_TOTPAGES,	T_TOTTRIES,
-    T_TO_COMPANY,T_TO_LOCATION,	T_TO_USER,	T_TO_VOICE,	T_USE_CONTCOVER,
+    T_TO_COMPANY,T_TO_LOCATION,	T_TO_USER,	T_TO_VOICE,	T_TSI,		T_USE_CONTCOVER,
     T_USE_ECM,	 T_USE_TAGLINE,	T_USE_XVRES,	T_USRKEY,	T_VRES,
     /*
      * SNPP tokens.
@@ -215,6 +214,11 @@ protected:
     /*
      * User authentication and login-related state.
      */
+#ifdef HAVE_PAM
+	pam_handle_t *pamh;		// handle to current pam session
+	bool	pam_chrooted;	// if already chrooted, PAM gets disabled
+#endif
+
     fxStr	passwd;			// encrypted user password
     fxStr	adminwd;		// encrypted passwd for admin privileges
     u_int	uid;			// client's ID
@@ -262,6 +266,7 @@ protected:
     JobDict	jobs;			// non-default jobs
     Job*	curJob;			// current job
     fxStr	jobFormat;		// job status format string
+    JobDict	blankJobs;		// jobs created during this session but not submitted
     /*
      * Receive queue-related state.
      */
@@ -344,6 +349,7 @@ protected:
     void loginRefused(const char* why);
 	bool pamCheck(const char* user=NULL, const char* pass=NULL);
 	bool pamIsAdmin(const char* user=NULL);
+	void pamEnd(int pamret);
     bool checkUser(const char*);
     bool checkuser(FILE*, const char *name);
     bool checkuser(const char *name);
