@@ -1,4 +1,4 @@
-/*	$Id: FaxClient.h,v 1.5 2003/02/08 22:49:56 darren Exp $ */
+/*	$Id: FaxClient.h,v 1.6 2005/03/14 18:06:07 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -274,8 +274,8 @@ public:
     /*
      * Retrieve information from the server.
      */
-    bool recvData(bool (*f)(void*, const char*, int, fxStr&),
-    void* arg, fxStr& emsg, u_long restart, const char* fmt, ...);
+    bool recvData(bool (*f)(int, const char*, int, fxStr&),
+    int arg, fxStr& emsg, u_long restart, const char* fmt, ...);
     bool recvZData(bool (*f)(void*, const char*, int, fxStr&),
     void* arg, fxStr& emsg, u_long restart, const char* fmt, ...);
     /*
