@@ -1,4 +1,4 @@
-/*	$Id: faxadduser.c,v 1.5 2005/01/10 04:52:10 darren Exp $ */
+/*	$Id: faxadduser.c,v 1.7 2006/01/09 17:18:31 aidan Exp $ */
 /*
  * Copyright (c) 1999 Robert Colquhoun
  *
@@ -35,8 +35,12 @@
 #include "config.h"
 #include "port.h"
 
+#if HAS_CRYPT_H
+#include <crypt.h>
+#endif
+
 #ifndef FAX_DEFAULT_UID
-#define FAX_DEFAULT_UID 6002
+#define FAX_DEFAULT_UID 60002
 #endif
 
 extern int optind;
