@@ -1,4 +1,4 @@
-/*	$Id: faxconfig.c,v 1.6 2003/04/15 21:44:03 tim Exp $ */
+/*	$Id: faxconfig.c,v 1.7 2005/07/30 01:14:58 lhoward Exp $ */
 /*
  * Copyright (c) 1995-1996 Sam Leffler
  * Copyright (c) 1995-1996 Silicon Graphics, Inc.
@@ -88,7 +88,7 @@ main(int argc, char** argv)
             }
         } else {
             snprintf(fifoname, sizeof(fifoname), "%s.%.*s", FAX_FIFO,
-                sizeof (fifoname) - sizeof (FAX_FIFO), devid);
+                (int) (sizeof(fifoname) - sizeof(FAX_FIFO)), devid);
         }
     } else {
         strcpy(fifoname, FAX_FIFO);
